<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0"
  xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:java="http://xml.apache.org/xslt/java"
  xmlns:util="xalan://org.greenstone.gsdl3.util.XSLTUtil"
  extension-element-prefixes="java util"
  exclude-result-prefixes="java util">

  <!-- style includes global params interface_name, library_name -->
  <xsl:include href="style.xsl"/>

  <xsl:output method="html"/>  
  
  <!-- the main page layout template is here -->
  <xsl:template match="page">
    <html>
      <head>
	<title>
	  <!-- put a space in the title in case the actual value is missing - mozilla will not display a page with no title-->
	  <xsl:call-template name="pageTitle"/><xsl:text> </xsl:text>
	</title>
	<xsl:call-template name="globalStyle"/>
	<xsl:call-template name="pageStyle"/>
      </head>
      <body>
	<xsl:attribute name="dir"><xsl:call-template name="direction"/></xsl:attribute>
	<div id="page-wrapper">
	  <xsl:call-template name="response" />
	  <xsl:call-template name="greenstoneFooter"/>
	</div>
      </body>
    </html>
  </xsl:template>

  <xsl:template name="pageTitle">
    <xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'gsdl')"/>
  </xsl:template>

  <!-- page specific style goes here -->
  <xsl:template name="pageStyle"/>

  <xsl:template match="pageResponse">
    <xsl:call-template name="pageBanner"/> 
    <xsl:apply-templates select="serviceList/service[@name='TextQuery']"/>
    <xsl:apply-templates select="collectionList"/>   
    <xsl:apply-templates select="serviceClusterList"/>
    <xsl:apply-templates select="serviceList"/>
  </xsl:template>

  <xsl:template name="pageBanner">
    <div id="banner">
      <p>
	<img src="interfaces/default/images/gsdlhead.gif"><xsl:attribute name="alt"><xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'gsdl')"/></xsl:attribute>
	</img>
      </p>
    </div>
    <div id="content">
      <xsl:call-template name="dividerBar">
	<xsl:with-param name="text" select="util:getInterfaceText($interface_name, /page/@lang, 'home.select_a_collection')"/> 
      </xsl:call-template>	
    </div>
  </xsl:template>

  <xsl:template match="collectionList">
    <ul id="collectionlist">
      <xsl:for-each select="collection"> 
	<li>
	  
	  <xsl:choose>
	    <xsl:when test="displayItem[@name='icon']">
              <a href="{$library_name}?a=p&amp;sa=about&amp;c={@name}">
                <img>
		  <xsl:attribute name="src">
		    <xsl:value-of select="metadataList/metadata[@name='httpPath']"/>/images/<xsl:value-of select="displayItem[@name='icon']"/>
		  </xsl:attribute>
		  <xsl:attribute name="alt">
		    <xsl:value-of select="displayItem[@name='name']"/>
		  </xsl:attribute>
		</img> 
	      </a>  
	    </xsl:when>
	    <xsl:otherwise>
	      <a class="noimage" href="{$library_name}?a=p&amp;sa=about&amp;c={@name}">  
		<xsl:value-of select="displayItem[@name='name']"/>
	      </a>
	    </xsl:otherwise>
	  </xsl:choose>         
	  
	</li>
      </xsl:for-each> 
    </ul>
  </xsl:template> 
  
  <xsl:template match="serviceClusterList">
    <xsl:for-each select="serviceCluster"> 
      <a href="{$library_name}?a=p&amp;sa=about&amp;c={@name}"><xsl:value-of select='@name'/><xsl:value-of select="displayItem[@name='name']"/></a>
    </xsl:for-each>
  </xsl:template>

  <xsl:template match="service[@name='TextQuery']">
    <div class="QuickSearch">
      <form name="QuickSearch" method="get" action="{$library_name}">
	<input type="hidden" name="a" value="q"/>
	<input type="hidden" name="rt" value="rd"/>
	<input type="hidden" name="s" value="{@name}"/>
	<input type="hidden" name="s1.collection" value="all"/>
	<input type="text" name="s1.query" size="20"/>
	<input type="submit"><xsl:attribute name="value"><xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'home.quick_search')"/></xsl:attribute></input>
      </form>
    </div>
  </xsl:template>

  <xsl:template match="serviceList">
    <xsl:call-template name="dividerBar"/>
    <ul id="servicelist">
      <xsl:for-each select="service[@type='query']">
	<li><a href="{$library_name}?a=q&amp;rt=d&amp;s={@name}"><xsl:value-of select="displayItem[@name='name']"/></a><xsl:value-of select="displayItem[@name='description']"/></li>
      </xsl:for-each>
      <!--uncomment to display an authentication link-->
      <!--<xsl:for-each select="service[@type='authen']">
      <li><a href="{$library_name}?a=g&amp;rt=r&amp;sa=authen&amp;s={@name}&amp;s1.aup=Login&amp;s1.un=&amp;s1.asn="><xsl:value-of select="displayItem[@name='name']"/></a><xsl:value-of select="displayItem[@name='description']"/></li>      </xsl:for-each>-->
      <!--uncomment to display a library interface link-->
      <!--<li><a href="{$library_name}?a=p&amp;sa=gli4gs3"><xsl:value-of select="util:getInterfaceText($interface_name, /page/@lang, 'home.librarian_interface')"/></a></li>-->
    </ul>
  </xsl:template>
</xsl:stylesheet>  


